#include <avr/io.h>
#define F_CPU 16000000
#include <util/delay.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "display.h"
#include "lcd.h"
#include "buzzer.h"

/* DISPLAY POS MACROS */
#define POS_MODE				0x49
#define POS_BET					0x44
#define POS_SOLD				0x05
#define POS_BEGIN_TOP_LINE		0x00
#define POS_BEGIN_BOTTOM_LINE	0x40
#define POS_FINAL				0x50

/* MODES MACROS */
#define BASIC_MODE "    BSC"
#define DOUBLE_MODE "    DBL"

void display_sold(int sold)
{
	char buffer[5];
	sprintf(buffer, "%d", sold);
	LCD_printAt(POS_SOLD, buffer);
	LCD_printAt(POS_FINAL, "");
}

void display_bet(int bet)
{
	char buffer[5];
	sprintf(buffer, "%d", bet);
	LCD_printAt(POS_BET, buffer);
	LCD_printAt(POS_FINAL, "");
}

void display_top_line(int sold)
{
	LCD_clear_top_line();
	LCD_printAt(POS_BEGIN_TOP_LINE, "SOLD: ");
	display_sold(sold);
	LCD_printAt(0x09, "    MOD");
	LCD_printAt(POS_FINAL, "");
}

void display_bottom_line(int bet)
{
	LCD_clear_bottom_line();
	LCD_printAt(POS_BEGIN_BOTTOM_LINE, "BET: ");
	display_bet(bet);
	LCD_printAt(POS_MODE, BASIC_MODE);
	LCD_printAt(POS_FINAL, "");
}

void display(int sold, int bet)
{
	display_top_line(sold);
	display_bottom_line(bet);
}

void clear_LCD()
{
	LCD_clear_top_line();
	LCD_clear_bottom_line();
}

void display_double_game()
{
	clear_LCD();
	LCD_printAt(POS_BEGIN_TOP_LINE, "RED? OR");
	LCD_printAt(0x09, "    MOD");
	LCD_printAt(POS_BEGIN_BOTTOM_LINE, "BLUE?");
	LCD_printAt(POS_MODE, DOUBLE_MODE);
}

int display_double_game_result(int right_colour, int chosen_colour)
{
	clear_LCD();
	LCD_printAt(POS_BEGIN_TOP_LINE, "RED ");
	LCD_printAt(0x09, "    MOD");
	LCD_printAt(POS_BEGIN_BOTTOM_LINE, "BLUE ");
	LCD_printAt(POS_MODE, DOUBLE_MODE);
	
	if (chosen_colour == 0)
	{
		if (right_colour == 0)
		{
			LCD_printAt(0x04, "RIGHT");
			LCD_printAt(POS_FINAL, "");
			ha_ha_ha();
			return 1;
		}
		else
		{
				LCD_printAt(0x04, "WRONG");
				LCD_printAt(POS_FINAL, "");
				sad_so_sad();
				return 0;
		}
	}
	else
	{
		if (chosen_colour == 1)
		{
			if (right_colour == 1)
			{
				LCD_printAt(0x45, "RIGHT");
				LCD_printAt(POS_FINAL, "");
				ha_ha_ha();
				return 1;
			}
			else
			{
				LCD_printAt(0x45, "WRONG");
				LCD_printAt(POS_FINAL, "");
				sad_so_sad();
				return 0;
			}
		}
	}
	return 0;
}

void display_end_game(int sold)
{
	clear_LCD();
	char buffer[5];
	sprintf(buffer, "%d", sold);
	LCD_printAt(POS_BEGIN_TOP_LINE, "YOU WON ");
	LCD_printAt(0x08, buffer);
	LCD_printAt(POS_BEGIN_BOTTOM_LINE, "CONGRATS! :)");
	LCD_printAt(POS_FINAL, "");
	ha_ha_ha();
}

void display_pot(int money)
{
	LCD_clear_bottom_line();
	LCD_printAt(0x40, "POT: ");
	char buffer[5];
	sprintf(buffer, "%d", money);
	LCD_printAt(0x44, buffer);
	LCD_printAt(POS_MODE, BASIC_MODE);
}