#include <avr/io.h>
#define F_CPU 16000000
#include <util/delay.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "lcd.h"
#include "init.h"
#include "display.h"
#include "turnoff.h"
#include "turnon.h"

void setLCD(int sold, int bet)
{
	clear_LCD();
	LCD_printAt(0x00, "SOLD: ");
	LCD_printAt(0x09, "    MOD");
	LCD_printAt(0x40, "BET: ");
	display_sold(sold);
	display_bet(bet);
	LCD_printAt(0x49, "    BSC");
}

void presetLEDs()
{
	turnOnCathods();
	tonLED31(1);
	tonLED32(1);
	tonLED33(1);
	tonLED34(1);
	tonLED35(1);
	
	tonLED21(2);
	tonLED22(2);
	tonLED23(2);
	tonLED23(2);
	tonLED25(2);
	
	tonLED11(3);
	tonLED12(3);
	tonLED13(3);
	tonLED14(3);
	tonLED15(3);
}

void IO_init()
{
	/*CATOD*/
	DDRA |= (1 << PA0);
	DDRA |= (1 << PA1);
	DDRA |= (1 << PA2);
	DDRA |= (1 << PA3);
	DDRA |= (1 << PA4);
	
	/*RED*/
	DDRB |= (1 << PB1);
	DDRB |= (1 << PB4);
	DDRB |= (1 << PB7);
	
	/*GREEN*/
	DDRB |= (1 << PB0);
	DDRB |= (1 << PB3);
	DDRB |= (1 << PB6);
	
	/*BLUE*/
	DDRD |= (1<< PD6);
	DDRB |= (1 << PB2);
	DDRB |= (1 << PB5);
	
	/*BUTOANE*/
	DDRD &= ~(1 << PC1); // DEC
	DDRD &= ~(1 << PD0); // GET_MONEY
	DDRD &= ~(1 << PD1); // INC
	DDRD &= ~(1 << PD3); // START
	DDRD &= ~(1 << PD4); // BLACK/WHITE
	/*PULL-UP BUTOANE*/
	PORTC |= (1 << PC1); // DEC
	PORTD |= (1 << PD0); // GET_MONEY
	PORTD |= (1 << PD1); // INC
	PORTD |= (1 << PD3); // START
	PORTD |= (1 << PD4); // BLACK/WHITE
	
	/*BUZZER*/
	DDRD |= (1 << PD5);
	
	turnOffTheLEDs();
	
	/*LCD backlight*/
	DDRC |= (1 << PC2);
	PORTC |= (1 << PC2);
}

int** alloc_matrix()
{
	int** matrix = malloc(5 * sizeof(int*));
	if (matrix == NULL)
	{
		return NULL;
	}
	matrix[0] = malloc(3 * sizeof(int));
	if (matrix[0] == NULL)
	{
		return NULL;
	}
	matrix[1] = malloc(3 * sizeof(int));
	if (matrix[1] == NULL)
	{
		return NULL;
	}
	matrix[2] = malloc(3 * sizeof(int));
	if (matrix[2] == NULL)
	{
		return NULL;
	}
	matrix[3] = malloc(3 * sizeof(int));
	if (matrix[3] == NULL)
	{
		return NULL;
	}
	matrix[4] = malloc(3 * sizeof(int));
	if (matrix[4] == NULL)
	{
		return NULL;
	}
	
	return matrix;
}

void freeMatrix(int** matrix)
{
	int i = 0;
	for (i = 0; i < 5; i++)
	{
		free(matrix[i]);
	}
	free(matrix);
}