/*
 * SlotMachine.c
 *
 * Created: 19-May-18 2:57:50 AM
 * Author : Alex
 */ 

#include <avr/io.h>
#define F_CPU 16000000
#include <util/delay.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "double_game.h"
#include "game.h"
#include "turnoff.h"
#include "turnon.h"
#include "lcd.h"
#include "display.h"
#include "init.h"
#include "buzzer.h"

/* MODES MACROS */
#define BASIC_MODE "    BSC"
#define DOUBLE_MODE "    DBL"

/* MAIN MACROS */
#define GET_MONEY PD0
#define INC PD1
#define DEC PC1
#define START PD3
#define DOUBLE PD4
#define FALSE 0
#define TRUE 1

int main() {
	IO_init();
	LCD_init();
	
	int sold = 1000;
	int bet = 50;
	setLCD(sold, bet);
	presetLEDs();
	
	uint8_t get_old = 0xff;
	uint8_t inc_old = 0xff;
	uint8_t dec_old = 0xff;
	uint8_t start_old = 0xff;
	uint8_t double_old = 0xff;
	
	int inc_pushed = FALSE;
	int dec_pushed = FALSE;
	int double_pushed = FALSE;
	int get_money_pushed = FALSE;
	int start_pushed = FALSE;
	int gameOn = FALSE;
	int money = 0;
	int collected = TRUE;
	
	int** matrix = alloc_matrix();
	if (matrix == NULL)
	{
		return -1;
	}

	while (TRUE)
	{
		uint8_t get_crt = PIND;
		uint8_t inc_crt = PIND;
		uint8_t dec_crt = PINC;
		uint8_t start_crt = PIND;
		uint8_t double_crt = PIND;
		
		/*****************************************************/
		/* GET MONEY */
		if ((get_old & (1 << GET_MONEY)) && !(get_crt & (1 << GET_MONEY)) && gameOn == 1)
		{
			get_money_pushed = TRUE;
		}
		
		if (get_money_pushed == TRUE)
		{
			if (gameOn == TRUE)
			{
				if (collected == FALSE)
				{
					sold += money;
					money = 0;
					collected = TRUE;
					display(sold, bet);
					_delay_ms(1000);
				}
				else
				{
					break;
				}
			}
		}
		get_money_pushed = FALSE;
		get_old = get_crt;
		_delay_ms(5);
		
		/*****************************************************/
		/* INCREMENT SOLD/BET */
		if ((inc_old & (1 << INC)) && !(inc_crt & (1 << INC)))
		{
			inc_pushed = TRUE;
		}
		
		if (inc_pushed == TRUE)
		{
			if (gameOn == TRUE)
			{
				if (collected == TRUE)
				{
					if (bet < 200)
					{
						bet += 10;
					}
					display_bottom_line(bet);
				}
			}
			else
			{
				if (sold < 30000)
				{
					sold += 1000;
				}
				display_top_line(sold);
			}
		}
		inc_pushed = FALSE;
		inc_old = inc_crt;
		_delay_ms(5);
		
		/*****************************************************/
		/* DECREMENT SOLD/BET */
		if ((dec_old & (1 << DEC)) && !(dec_crt & (1 << DEC)))
		{
			dec_pushed = TRUE;
		}
		
		if (dec_pushed == TRUE)
		{
			if (gameOn == TRUE)
			{
				if (collected == TRUE)
				{
					if (bet > 20)
					{
						bet -= 10;
					}
					_delay_ms(200);
					display_bottom_line(bet);
				}
			}
			else
			{
				if (sold > 1000)
				{
					sold -= 1000;
				}
				_delay_ms(200);
				display_top_line(sold);
			}
		}
		dec_pushed = FALSE;
		dec_old = dec_crt;
		_delay_ms(5);
		
		/*****************************************************/
		/* START */
		if ((start_old & (1 << START)) && !(start_crt & (1 << START)))
		{
			start_pushed = TRUE;
			gameOn = TRUE;
		}
		
		if (start_pushed == TRUE)
		{
			if (collected == FALSE)
			{
				sold += money;
				collected = TRUE;
				setLCD(sold, bet);
				_delay_ms(1000);
			}
			else
			{
				if (bet > sold)
				{
					bet = sold;
				}
				
				sold -= bet;
				display_top_line(sold);
				_delay_ms(500);
				
				int factor = roll_matrix(matrix);
				money = factor * bet;
				if (money != 0)
				{
					ha_ha_ha();
				}
				else
				{
					sad_so_sad();
				}
				collected = FALSE;
				_delay_ms(500);
				display_pot(money);
				_delay_ms(500);
			}
		}
		start_pushed = FALSE;
		start_old = start_crt;
		_delay_ms(5);
		
		/*****************************************************/
		/* DOUBLE */
		if ((double_old & (1 << DOUBLE)) && !(double_crt & (1 << DOUBLE)) && gameOn == TRUE)
		{
			double_pushed = TRUE;
		}
		
		if (double_pushed == TRUE)
		{
			money = double_game(money);
			sold += money;
			money = 0;
			collected = TRUE;
			setLCD(sold, bet);
		}
		double_pushed = FALSE;
		double_old = double_crt;
		_delay_ms(5);
	}
	
	freeMatrix(matrix);
	
	while (TRUE)
	{
		display_end_game(sold);
		break;
	}
}